@@ -786,8 +786,11 @@ module Ole # :nodoc:
 				@name = name
 			end
 
+			# needed to add reset of @name_lookup here. might be better to just
+			# remove this method as its only used in one place anyway.
 			def children= children
 				@children = []
+				@name_lookup = {}
 				children.each { |child| self << child }
 			end
 
